%define major 		20
%define pangomajor	20
%define gi_major	1.0
%define gi_major2	2.0

%define libname		%mklibname %{name} %{major}
%define libname_pango	%mklibname %{name}-pango %{pangomajor}
%define develname 	%mklibname -d %{name}
%define girname 	%mklibname %{name}-gir %{gi_major}
%define girname_pango	%mklibname %{name}-pango-gir %{gi_major}

%define girname2 	%mklibname %{name}-gir %{gi_major2}
%define girname_pango2	%mklibname %{name}-pango-gir %{gi_major2}

%define url_ver	%(echo %{version}|cut -d. -f1,2)

Name:		cogl
Version:	1.22.8
Release:	%mkrel 3
Summary:	A library for using 3D graphics hardware to draw pretty pictures
Group:		System/Libraries
License:	LGPLv2+
URL:		https://gitlab.gnome.org/GNOME/cogl
Source0:	https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
# Vaguely related to https://bugzilla.gnome.org/show_bug.cgi?id=772419
# but on the 1.22 branch, and the static inline in the header is gross
# ajax promises he'll clean this up.
Patch0: 0001-egl-Use-eglGetPlatformDisplay-not-eglGetDisplay.patch

# "GL_ARB_shader_texture_lod" is used to do lod biased texturing. It
# make achieve faster blurring of images instead of using large blur radius.
Patch1: 0002-add-GL_ARB_shader_texture_lod-support.patch

# "copy_sub_image" is used to implement feature similar with kwin blur
# effect by being abel to copy partial of framebuffer contents as texture
# and do post blurring.
Patch2: 0003-texture-support-copy_sub_image.patch

# Fix building against libglvnd-provided EGL headers
# https://gitlab.gnome.org/GNOME/cogl/-/merge_requests/17
BuildRequires:	mesaegl-devel
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xfixes) >= 3
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xcomposite) >= 0.4
BuildRequires:	pkgconfig(gobject-2.0) >= 2.28.0
BuildRequires:	pkgconfig(gmodule-no-export-2.0)
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(cairo) >= 1.10
BuildRequires:	pkgconfig(pangocairo) >= 1.20
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(gtk-doc)
# ovitters: Wayland support + required KMS support
BuildRequires:	pkgconfig(wayland-egl) >= 1.0.0
BuildRequires:	pkgconfig(wayland-client) >= 1.0.0
BuildRequires:	pkgconfig(wayland-server) >= 1.1.90
BuildRequires:	pkgconfig(gbm)

%description
Cogl is a small open source library for using 3D graphics hardware to draw
pretty pictures. The API departs from the flat state machine style of
OpenGL and is designed to make it easy to write orthogonal components that
can render without stepping on each others toes.

As well aiming for a nice API, we think having a single library as opposed
to an API specification like OpenGL has a few advantages too; like being
able to paper over the inconsistencies/bugs of different OpenGL
implementations in a centralized place, not to mention the myriad of OpenGL
extensions. It also means we are in a better position to provide utility
APIs that help software developers since they only need to be implemented
once and there is no risk of inconsistency between implementations.

Having other backends, besides OpenGL, such as drm, Gallium or D3D are
options we are interested in for the future.

#--------------------------------------------------------------------

%package i18n
Summary:	Translations for %{name}
Group:		System/Internationalization
Obsoletes:	%{name} < 1.9.2
BuildArch:	noarch

%description i18n
This contains the translation data for %{name}.

%files i18n -f %{name}.lang

#--------------------------------------------------------------------

%package -n %{libname}
Summary:	A library for using 3D graphics hardware to draw pretty pictures
Group:		System/Libraries
Requires:	%{name}-i18n

%description -n %{libname}
Cogl is a small open source library for using 3D graphics hardware to draw
pretty pictures. The API departs from the flat state machine style of
OpenGL and is designed to make it easy to write orthogonal components that
can render without stepping on each others toes.

As well aiming for a nice API, we think having a single library as opposed
to an API specification like OpenGL has a few advantages too; like being
able to paper over the inconsistencies/bugs of different OpenGL
implementations in a centralized place, not to mention the myriad of OpenGL
extensions. It also means we are in a better position to provide utility
APIs that help software developers since they only need to be implemented
once and there is no risk of inconsistency between implementations.

Having other backends, besides OpenGL, such as drm, Gallium or D3D are
options we are interested in for the future.

%files -n %{libname}
%{_libdir}/libcogl.so.%{major}{,.*}
%{_libdir}/libcogl-path.so.%{major}{,.*}

#--------------------------------------------------------------------

%package -n %{libname_pango}
Summary:	A library for using 3D graphics hardware to draw pretty pictures
Group:		System/Libraries
Requires:	%{name}-i18n

%description -n %{libname_pango}
Cogl is a small open source library for using 3D graphics hardware to draw
pretty pictures. The API departs from the flat state machine style of
OpenGL and is designed to make it easy to write orthogonal components that
can render without stepping on each others toes.

As well aiming for a nice API, we think having a single library as opposed
to an API specification like OpenGL has a few advantages too; like being
able to paper over the inconsistencies/bugs of different OpenGL
implementations in a centralized place, not to mention the myriad of OpenGL
extensions. It also means we are in a better position to provide utility
APIs that help software developers since they only need to be implemented
once and there is no risk of inconsistency between implementations.

Having other backends, besides OpenGL, such as drm, Gallium or D3D are
options we are interested in for the future.

%files -n %{libname_pango}
%{_libdir}/libcogl-pango.so.%{pangomajor}{,.*}

#--------------------------------------------------------------------

%package -n %{girname}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}
Conflicts:	%{mklibname %{name}-gir 0.0} < %{version}
Conflicts:	%{mklibname clutter 1.0 0} < 1.7.2

%description -n %{girname}
GObject Introspection interface description for %{name}.

%files -n %{girname}
%{_libdir}/girepository-1.0/Cogl-%{gi_major}.typelib

#--------------------------------------------------------------------

%package -n %{girname_pango}
Summary:	GObject Introspection interface description for %{name}-pango
Group:		System/Libraries
Requires:	%{libname_pango} = %{version}-%{release}
Conflicts:	%{_lib}cogl-gir0.0 < %{version}

%description -n %{girname_pango}
GObject Introspection interface description for %{name}-pango.

%files -n %{girname_pango}
%{_libdir}/girepository-1.0/CoglPango-%{gi_major}.typelib

#--------------------------------------------------------------------

%package -n %{girname2}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n %{girname2}
GObject Introspection interface description for %{name}.

%files -n %{girname2}
%{_libdir}/girepository-1.0/Cogl-%{gi_major2}.typelib

#--------------------------------------------------------------------

%package -n %{girname_pango2}
Summary:	GObject Introspection interface description for %{name}-pango
Group:		System/Libraries
Requires:	%{libname_pango} = %{version}-%{release}

%description -n %{girname_pango2}
GObject Introspection interface description for %{name}-pango.

%files -n %{girname_pango2}
%{_libdir}/girepository-1.0/CoglPango-%{gi_major2}.typelib

#--------------------------------------------------------------------

%package -n %{develname}
Summary:	%{name} development environment
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Requires:	%{libname_pango} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	mesaegl-devel
Requires:	pkgconfig(egl)
Requires:	pkgconfig(gl)
Requires:	%{girname} = %{version}-%{release}
Requires:	%{girname2} = %{version}-%{release}
Requires:	%{girname_pango} = %{version}-%{release}
Requires:	%{girname_pango2} = %{version}-%{release}
Conflicts:	%{mklibname -d clutter 1.0} <= 1.6.16

%description -n %{develname}
Header files and libraries for building and developing apps with %{name}.

%files -n %{develname}
%doc NEWS README ChangeLog
%{_includedir}/cogl
%{_libdir}/libcogl*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/Cogl*-%{gi_major}.gir
%{_datadir}/gir-1.0/Cogl*-%{gi_major2}.gir

#--------------------------------------------------------------------

%package doc
Summary:	Documentation for %{name}
Group:		Documentation 
Requires:	%{name}-devel = %{version}-%{release}
BuildArch:	noarch

%description doc
This package contains documentation for %{name}.

%files doc
%{_datadir}/gtk-doc/html/cogl
%{_datadir}/gtk-doc/html/cogl-2.0-experimental

#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
CFLAGS="%{optflags} -fPIC"

%configure \
	--enable-cairo=yes \
	--enable-gdk-pixbuf=yes \
	--enable-cogl-pango=yes \
	--enable-glx=yes \
	--enable-gtk-doc \
	--enable-introspection=yes \
	--enable-examples-install=no \
	--enable-wayland-egl-server=yes \
	--enable-wayland-egl-platform=yes \
	--enable-kms-egl-platform
%make_build

%install
%make_install

#Remove examples
rm -rf %{buildroot}%{_datadir}/%{name}/examples-data/

#Remove libtool archives.
find %{buildroot} -name "*.la" -delete

%find_lang %{name}


%changelog
* Fri Oct 23 2020 akien <akien> 1.22.8-3.mga8
+ Revision: 1638812
- Make devel package require mesaegl-devel, it's included by some headers

* Thu Oct 22 2020 akien <akien> 1.22.8-2.mga8
+ Revision: 1638659
- BR mesaegl-devel explicitly

* Thu Jun 04 2020 ovitters <ovitters> 1.22.8-1.mga8
+ Revision: 1590319
- new version 1.22.8
- dropped merged patch cogl-1.22.6-mesa-19.3.patch

* Tue Mar 10 2020 ovitters <ovitters> 1.22.6-1.mga8
+ Revision: 1555190
- new version 1.22.6
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Dec 27 2019 wally <wally> 1.22.4-1.mga8
+ Revision: 1471028
- replace deprecated %%makeinstall_std

* Tue Apr 23 2019 ovitters <ovitters> 1.22.4-1.mga7
+ Revision: 1394948
- new version 1.22.4
- dropped merged patch e20d81b1627b09494c00fd29f952fc17e618af46..e0fda738232d6a1c69a150d7528a970887fb459f.patch

* Thu Mar 21 2019 shlomif <shlomif> 1.22.2-5.mga7
+ Revision: 1379448
- Rebuild for missing signatures

* Thu Mar 21 2019 tv <tv> 1.22.2-4.mga7
+ Revision: 1379419
- Add GL_ARB_shader_texture_lod and copy_sub_image support (#1421055)

* Sun Sep 23 2018 umeabot <umeabot> 1.22.2-3.mga7
+ Revision: 1296666
- Mageia 7 Mass Rebuild

* Sun Feb 19 2017 ovitters <ovitters> 1.22.2-2.mga6
+ Revision: 1086976
- add upstream patch to avoid resize confusion

* Sat Aug 27 2016 ovitters <ovitters> 1.22.2-1.mga6
+ Revision: 1049193
- new version 1.22.2

* Thu Feb 11 2016 umeabot <umeabot> 1.22.0-2.mga6
+ Revision: 953640
- Mageia 6 Mass Rebuild

* Wed Sep 16 2015 ovitters <ovitters> 1.22.0-1.mga6
+ Revision: 879935
- new version 1.22.0

* Fri Aug 21 2015 ovitters <ovitters> 1.21.2-1.mga6
+ Revision: 867964
- new version 1.21.2

* Sun Jun 28 2015 wally <wally> 1.20.0-2.mga6
+ Revision: 847166
- add requires for gir pkg to devel pkg

* Sat Jun 20 2015 ovitters <ovitters> 1.20.0-1.mga6
+ Revision: 836865
- new version 1.20.0
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 tv <tv> 1.18.2-4.mga5
+ Revision: 731114
- rebuild so that it picks typelib() requires

* Thu Sep 18 2014 umeabot <umeabot> 1.18.2-3.mga5
+ Revision: 693656
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.18.2-2.mga5
+ Revision: 678469
- Mageia 5 Mass Rebuild

* Fri Jul 04 2014 ovitters <ovitters> 1.18.2-1.mga5
+ Revision: 643255
- new version 1.18.2

* Fri Mar 21 2014 ovitters <ovitters> 1.18.0-1.mga5
+ Revision: 606460
- also package the 2.0 API
- new version 1.18.0

* Sat Feb 22 2014 tv <tv> 1.17.4-1.mga5
+ Revision: 595434
- bump libcogl-pango major too
- bump major
+ ovitters <ovitters>
- new version 1.17.4

* Wed Feb 05 2014 ovitters <ovitters> 1.17.2-1.mga5
+ Revision: 583939
- update major
- new version 1.17.2

* Tue Feb 04 2014 ovitters <ovitters> 1.16.2-1.mga5
+ Revision: 582482
- new version 1.16.2

* Sat Oct 19 2013 umeabot <umeabot> 1.16.0-2.mga4
+ Revision: 536453
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 ovitters <ovitters> 1.16.0-1.mga4
+ Revision: 484310
- new version 1.16.0

* Thu Sep 05 2013 ovitters <ovitters> 1.15.10-3.mga4
+ Revision: 475242
- enable KMS support (also needed for Wayland)

* Thu Sep 05 2013 ovitters <ovitters> 1.15.10-2.mga4
+ Revision: 475228
- enable Wayland support

* Mon Sep 02 2013 ovitters <ovitters> 1.15.10-1.mga4
+ Revision: 474448
- new version 1.15.10

* Tue Aug 20 2013 ovitters <ovitters> 1.15.8-1.mga4
+ Revision: 468319
- new version 1.15.8

* Tue Aug 20 2013 ovitters <ovitters> 1.15.6-1.mga4
+ Revision: 468310
- new version 1.15.6

* Thu Aug 01 2013 dams <dams> 1.15.4-1.mga4
+ Revision: 462299
- update major
+ ovitters <ovitters>
- new version 1.15.4

* Sun Jul 14 2013 sander85 <sander85> 1.15.2-1.mga4
+ Revision: 454245
- New version: 1.15.2

* Mon Jun 03 2013 tv <tv> 1.14.0-2.mga4
+ Revision: 436161
- rebuild for new libpng

* Fri May 24 2013 dams <dams> 1.14.0-1.mga4
+ Revision: 426266
- new version 1.14.0

* Fri Jan 11 2013 umeabot <umeabot> 1.12.0-3.mga3
+ Revision: 347995
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 14 2012 ennael <ennael> 1.12.0-2.mga3
+ Revision: 305600
- Documentation group

* Mon Sep 24 2012 mitya <mitya> 1.12.0-1.mga3
+ Revision: 297153
- fix doc build
- bump library major
+ ovitters <ovitters>
- new version 1.12.0

* Thu Jul 19 2012 fwang <fwang> 1.10.4-2.mga3
+ Revision: 272505
- fix requires on devel package

* Tue Jul 17 2012 ovitters <ovitters> 1.10.4-1.mga3
+ Revision: 271953
- drop link patch (not needed anymore)
- new version 1.10.4

* Thu Apr 19 2012 ovitters <ovitters> 1.10.2-1.mga2
+ Revision: 231785
- new version 1.10.2

* Tue Mar 20 2012 ovitters <ovitters> 1.10.0-1.mga2
+ Revision: 225079
- new version 1.10.0

* Tue Mar 06 2012 fwang <fwang> 1.9.8-1.mga2
+ Revision: 219603
- update libmajor
- new version 1.9.8

* Thu Feb 23 2012 fwang <fwang> 1.9.6-3.mga2
+ Revision: 212479
- add requires on gl due to inclusion of GL/gl.h

* Wed Feb 22 2012 tv <tv> 1.9.6-2.mga2
+ Revision: 212418
- fix hard version-release requires on i18n sub package with defeats the purpose of libification

* Wed Feb 22 2012 wally <wally> 1.9.6-1.mga2
+ Revision: 212291
- new version 1.9.6
- new major 8
- drop unneeded P1

* Tue Jan 17 2012 wally <wally> 1.9.4-2.mga2
+ Revision: 197508
- add patch to fix devel pkg requires
+ fwang <fwang>
- drop hard version req on i18n

* Tue Jan 17 2012 fwang <fwang> 1.9.4-1.mga2
+ Revision: 197204
- update libmajor
- new version 1.9.4

* Tue Nov 22 2011 wally <wally> 1.9.2-3.mga2
+ Revision: 170999
- enable gdk-pixbuf support
- clean BRs and use pkgconfig style

* Tue Nov 22 2011 wally <wally> 1.9.2-2.mga2
+ Revision: 170978
- fix doc pkg requires

* Tue Nov 22 2011 wally <wally> 1.9.2-1.mga2
+ Revision: 170959
- new version 1.9.2
- new major 6
- create i18n package for translations
- disable examples installation for sure

* Mon Oct 17 2011 wally <wally> 1.8.2-1.mga2
+ Revision: 155787
- new version 1.8.2

* Mon Sep 19 2011 wally <wally> 1.8.0-1.mga2
+ Revision: 145673
- new version 1.8.0
- new major 5 for cogl

* Tue Sep 06 2011 tv <tv> 1.7.8-1.mga2
+ Revision: 139400
- new release
- use xz sources
+ wally <wally>
- new version 1.7.6
- add patch to fix build
- make lib packages to not require gir ones
- clean .spec a bit
+ fwang <fwang>
- new version 1.7.4

* Fri Jul 15 2011 wally <wally> 1.7.2-5.mga2
+ Revision: 124377
- add more conflicts

* Thu Jul 07 2011 wally <wally> 1.7.2-4.mga2
+ Revision: 119896
- rebuild against new rpm-setup

* Tue Jul 05 2011 wally <wally> 1.7.2-3.mga2
+ Revision: 118926
- add subpackage for cogl-pango gir .typelib
- fix gir .typelib package summaries
- add gi_major check to file list
- add conflicts

* Tue Jul 05 2011 dmorgan <dmorgan> 1.7.2-2.mga2
+ Revision: 118862
- Make the lib package requires the gir one

* Tue Jul 05 2011 wally <wally> 1.7.2-1.mga2
+ Revision: 118689
- new version 1.7.2
- new major 1 for main lib
- clean .spec a bit

* Mon Jul 04 2011 wally <wally> 1.7.0-4.mga2
+ Revision: 118263
- add conflicts

* Mon Jul 04 2011 wally <wally> 1.7.0-3.mga2
+ Revision: 118082
- add more general provides to -devel package
- handle -devel package requires with find-requires script
- use configure2_5x macro

* Sun Jul 03 2011 dmorgan <dmorgan> 1.7.0-2.mga2
+ Revision: 117804
- Fix requires

* Sun Jul 03 2011 dmorgan <dmorgan> 1.7.0-1.mga2
+ Revision: 117702
- Fix buildRequires
- Fix buildRequires
- imported package cogl

